import { createEffect } from 'solid-js';
import { createRouteData, refetchRouteData, useRouteData } from 'solid-start';
import { adminCredentials, CheckCredentials } from '~/components/credentials';
import Users from '~/components/users';
import { adminDbExists } from '~/lib/admin-db-exists';
import { createAdminDb } from '~/lib/create-admin-db';
import { headersWithAuth } from '~/lib/headers-with-auth';

export function routeData() {
  return createRouteData(async () => {
    if (!(await adminDbExists())) {
      await createAdminDb();
    }

    const credentials = adminCredentials();
    if (!credentials) {
      return null;
    }
    const { database } = credentials;
    const headers = headersWithAuth();
    if (!headers) {
      return null;
    }
    headers.set('Content-type', 'application/json; charset=UTF-8');
    const response = await fetch(`${database}/dyomedea_users/_all_docs`, {
      method: 'POST',
      mode: 'cors',
      headers,
      body: JSON.stringify({
        include_docs: true,
        startkey: 'user:',
        endkey: 'user:\ufff0',
      }),
    });

    const results = await response.json();
    console.log({ caller: 'user route / routeData', results });
    return results.rows;
  });
}

createEffect(() => {
  const credentials = adminCredentials();
  if (!!credentials) {
    console.log({
      caller: 'routes/user/index.tsx / createEffect',
      adminCredentials: credentials,
    });
    refetchRouteData();
  }
});

export default () => {
  const users = useRouteData<typeof routeData>();
  // const users = routeData();
  return (
    <main>
      <h1>Users</h1>
      <CheckCredentials>
        <Users users={users} />
      </CheckCredentials>
    </main>
  );
};
